@@ -276,10 +276,9 @@ class Insight_Definition:
                                    continue
                             else:
                                 ids.append(column["id"])
-                if (len(ids) > 1):
-                    settings[field + "_id"] = ids
-                else:
-                    settings[field + "_id"] = ids[0]
+
+                settings[field + "_id"] = ids
+
             else:
                 for field in field_codes.keys():
                     for column in columns:
